#[repr(u32)]pub enum ClientDownloadBlobError {
NetworkRateLimit = 1,
Network = 2,
NotFound = 3,
NoSpace = 4,
Other = 5,
}Variants
NetworkRateLimit = 1
HTTP GET failed with server status 429 “Too Many Requests”.
Network = 2
Download failed because of networking related reasons.
NotFound = 3
Download failed because the remote file could not be found.
NoSpace = 4
Download failed because the device is out of space.
Other = 5
Download failed for unspecified reasons.
Implementations
Sourceimpl ClientDownloadBlobError
impl ClientDownloadBlobError
pub fn from_primitive(prim: u32) -> Option<Self>
pub const fn into_primitive(self) -> u32