#[repr(C)]pub struct ClientDownloadBlobResponse {
pub size: u64,
}Fields
size: u64Trait Implementations
Sourceimpl Clone for ClientDownloadBlobResponse
impl Clone for ClientDownloadBlobResponse
Sourcefn clone(&self) -> ClientDownloadBlobResponse
fn clone(&self) -> ClientDownloadBlobResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientDownloadBlobResponse
impl Debug for ClientDownloadBlobResponse
Sourceimpl<D: ResourceDialect> Decode<ClientDownloadBlobResponse, D> for ClientDownloadBlobResponse
impl<D: ResourceDialect> Decode<ClientDownloadBlobResponse, D> for ClientDownloadBlobResponse
Sourceimpl<D: ResourceDialect> Encode<ClientDownloadBlobResponse, D> for &ClientDownloadBlobResponse
impl<D: ResourceDialect> Encode<ClientDownloadBlobResponse, D> for &ClientDownloadBlobResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u64, D>> Encode<ClientDownloadBlobResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u64, D>> Encode<ClientDownloadBlobResponse, D> for (T0,)
Sourceimpl Hash for ClientDownloadBlobResponse
impl Hash for ClientDownloadBlobResponse
Sourceimpl Ord for ClientDownloadBlobResponse
impl Ord for ClientDownloadBlobResponse
Sourcefn cmp(&self, other: &ClientDownloadBlobResponse) -> Ordering
fn cmp(&self, other: &ClientDownloadBlobResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ClientDownloadBlobResponse
impl PartialOrd for ClientDownloadBlobResponse
Sourceimpl TypeMarker for ClientDownloadBlobResponse
impl TypeMarker for ClientDownloadBlobResponse
Sourcetype Owned = ClientDownloadBlobResponse
type Owned = ClientDownloadBlobResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ClientDownloadBlobResponse
impl ValueTypeMarker for ClientDownloadBlobResponse
Sourcetype Borrowed<'a> = &'a ClientDownloadBlobResponse
type Borrowed<'a> = &'a ClientDownloadBlobResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for ClientDownloadBlobResponse
impl Eq for ClientDownloadBlobResponse
impl Persistable for ClientDownloadBlobResponse
impl StructuralPartialEq for ClientDownloadBlobResponse